==> blesta-5.10.2.zip: blesta/components/modules/virtualmin/language/zh_cn/virtualmin.php <==
<?php
/**
 * Virtualmin
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Virtualmin.service_field.confirm_password'] = '确认密码';
$lang['Virtualmin.!error.virtualmin_password.valid'] = '密码长度至少为 8 个字符。';
$lang['Virtualmin.!error.virtualmin_username.length'] = '用户名长度必须在 1 到 16 个字符之间。';
$lang['Virtualmin.!error.virtualmin_username.test'] = '用户名不得以 "test "开头。';
$lang['Virtualmin.!error.virtualmin_username.format'] = '用户名只能包含字母和数字，且不得以数字开头。';
$lang['Virtualmin.!error.virtualmin_domain.test'] = '域名不能以 "test "开头。';
$lang['Virtualmin.!error.virtualmin_domain.format'] = '请输入有效的域名，如 domain.com。';
$lang['Virtualmin.!error.module_row.missing'] = '发生内部错误。模块行不可用。';
$lang['Virtualmin.!error.api.internal'] = '发生内部错误，或服务器未响应请求。';
$lang['Virtualmin.!error.meta[template].empty'] = '需要一个 VirtualMin 模板。';
$lang['Virtualmin.!error.meta[plan].empty'] = '需要 VirtualMin 计划。';
$lang['Virtualmin.!error.account_limit_valid'] = '请输入有效的账户限额。';
$lang['Virtualmin.!error.password_valid_connection'] = '无法建立与服务器的连接。请检查主机名、用户名、密码和端口是否正确。';
$lang['Virtualmin.!error.password_valid'] = '密码似乎无效。';
$lang['Virtualmin.!error.port_valid'] = '端口似乎无效。';
$lang['Virtualmin.!error.user_name_valid'] = '用户名似乎无效。';
$lang['Virtualmin.!error.host_name_valid'] = '主机名似乎无效。';
$lang['Virtualmin.!error.server_name_valid'] = '必须输入服务器标签。';
$lang['Virtualmin.service_field.tooltip.password'] = '您可以将密码留空，以便自动生成密码。';
$lang['Virtualmin.service_field.tooltip.username'] = '用户名可以留空，以便自动生成。';
$lang['Virtualmin.service_info.option_login'] = '登录';
$lang['Virtualmin.service_info.options'] = '选项';
$lang['Virtualmin.service_info.server'] = '服务器';
$lang['Virtualmin.service_info.password'] = '密码';
$lang['Virtualmin.service_info.username'] = '用户名';
$lang['Virtualmin.tab_stats.info.maximum_mailboxes'] = '最大邮箱数';
$lang['Virtualmin.tab_stats.info.maximum_databases'] = '最大数据库数';
$lang['Virtualmin.tab_stats.info.databases_count'] = '数据库计数';
$lang['Virtualmin.tab_stats.info.databases_size'] = '数据库大小';
$lang['Virtualmin.tab_stats.info.disk_used'] = '使用的磁盘';
$lang['Virtualmin.tab_stats.info_heading.value'] = '价值';
$lang['Virtualmin.tab_stats.info_heading.field'] = '现场';
$lang['Virtualmin.tab_stats.info_title'] = '信息';
$lang['Virtualmin.tab_client_actions.field_password_submit'] = '更新密码';
$lang['Virtualmin.tab_client_actions.field_virtualmin_confirm_password'] = '确认密码';
$lang['Virtualmin.tab_client_actions.field_virtualmin_password'] = '密码';
$lang['Virtualmin.tab_client_actions.change_password'] = '更改密码';
$lang['Virtualmin.service_field.password'] = '密码';
$lang['Virtualmin.service_field.username'] = '用户名';
$lang['Virtualmin.service_field.domain'] = '域名';
$lang['Virtualmin.package_fields.template'] = '虚拟迷你模板';
$lang['Virtualmin.package_fields.plan'] = '虚拟货币计划';
$lang['Virtualmin.row_meta.account_limit'] = '账户限额';
$lang['Virtualmin.row_meta.use_ssl'] = '连接应用程序接口时使用 SSL（推荐）';
$lang['Virtualmin.row_meta.port'] = '港口';
$lang['Virtualmin.row_meta.password'] = '密码';
$lang['Virtualmin.row_meta.user_name'] = '用户名';
$lang['Virtualmin.row_meta.host_name'] = '主机名';
$lang['Virtualmin.row_meta.server_name'] = '服务器标签';
$lang['Virtualmin.edit_row.add_btn'] = '编辑服务器';
$lang['Virtualmin.edit_row.basic_title'] = '基本设置';
$lang['Virtualmin.edit_row.box_title'] = '编辑 VirtualMin 服务器';
$lang['Virtualmin.add_row.add_btn'] = '添加服务器';
$lang['Virtualmin.add_row.basic_title'] = '基本设置';
$lang['Virtualmin.add_row.box_title'] = '添加 VirtualMin 服务器';
$lang['Virtualmin.order_options.first'] = '第一个非满员服务器';
$lang['Virtualmin.manage.module_groups_no_results'] = '没有服务器组。';
$lang['Virtualmin.manage.module_rows_no_results'] = '没有服务器。';
$lang['Virtualmin.manage.module_groups.confirm_delete'] = '您确定要删除此服务器组吗？';
$lang['Virtualmin.manage.module_rows.confirm_delete'] = '您确定要删除这个服务器吗？';
$lang['Virtualmin.manage.module_groups.delete'] = '删除';
$lang['Virtualmin.manage.module_rows.delete'] = '删除';
$lang['Virtualmin.manage.module_groups.edit'] = '编辑';
$lang['Virtualmin.manage.module_rows.edit'] = '编辑';
$lang['Virtualmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['Virtualmin.manage.module_groups_heading.options'] = '选项';
$lang['Virtualmin.manage.module_groups_heading.servers'] = '服务器数量';
$lang['Virtualmin.manage.module_groups_heading.name'] = '组名';
$lang['Virtualmin.manage.module_rows_heading.options'] = '选项';
$lang['Virtualmin.manage.module_rows_heading.accounts'] = '账户';
$lang['Virtualmin.manage.module_rows_heading.port'] = '港口';
$lang['Virtualmin.manage.module_rows_heading.hostname'] = '主机名';
$lang['Virtualmin.manage.module_rows_heading.name'] = '服务器标签';
$lang['Virtualmin.manage.module_groups_title'] = '服务器组';
$lang['Virtualmin.manage.module_rows_title'] = '服务器';
$lang['Virtualmin.add_module_group'] = '添加服务器组';
$lang['Virtualmin.add_module_row'] = '添加服务器';
$lang['Virtualmin.tab_client_actions'] = '行动';
$lang['Virtualmin.tab_stats'] = '统计资料';
$lang['Virtualmin.module_group'] = '服务器组';
$lang['Virtualmin.module_row_plural'] = '服务器';
$lang['Virtualmin.module_row'] = '服务器';
$lang['Virtualmin.description'] = 'Virtualmin 是一个域名主机和网站控制面板，能够创建和管理多个域名，有开源和商业两个版本。它基于 Webmin。';
$lang['Virtualmin.name'] = 'VirtualMin';

==> blesta-5.11.4.zip: blesta/components/modules/virtualmin/language/zh_cn/virtualmin.php <==
<?php
/**
 * Virtualmin
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Virtualmin.service_field.confirm_password'] = '确认密码';
$lang['Virtualmin.!error.virtualmin_password.valid'] = '密码长度至少为 8 个字符。';
$lang['Virtualmin.!error.virtualmin_username.length'] = '用户名长度必须在 1 到 16 个字符之间。';
$lang['Virtualmin.!error.virtualmin_username.test'] = '用户名不得以 "test "开头。';
$lang['Virtualmin.!error.virtualmin_username.format'] = '用户名只能包含字母和数字，且不得以数字开头。';
$lang['Virtualmin.!error.virtualmin_domain.test'] = '域名不能以 "test "开头。';
$lang['Virtualmin.!error.virtualmin_domain.format'] = '请输入有效的域名，如 domain.com。';
$lang['Virtualmin.!error.module_row.missing'] = '发生内部错误。模块行不可用。';
$lang['Virtualmin.!error.api.internal'] = '发生内部错误，或服务器未响应请求。';
$lang['Virtualmin.!error.meta[template].empty'] = '需要一个 VirtualMin 模板。';
$lang['Virtualmin.!error.meta[plan].empty'] = '需要 VirtualMin 计划。';
$lang['Virtualmin.!error.account_limit_valid'] = '请输入有效的账户限额。';
$lang['Virtualmin.!error.password_valid_connection'] = '无法建立与服务器的连接。请检查主机名、用户名、密码和端口是否正确。';
$lang['Virtualmin.!error.password_valid'] = '密码似乎无效。';
$lang['Virtualmin.!error.port_valid'] = '端口似乎无效。';
$lang['Virtualmin.!error.user_name_valid'] = '用户名似乎无效。';
$lang['Virtualmin.!error.host_name_valid'] = '主机名似乎无效。';
$lang['Virtualmin.!error.server_name_valid'] = '必须输入服务器标签。';
$lang['Virtualmin.service_field.tooltip.password'] = '您可以将密码留空，以便自动生成密码。';
$lang['Virtualmin.service_field.tooltip.username'] = '用户名可以留空，以便自动生成。';
$lang['Virtualmin.service_info.option_login'] = '登录';
$lang['Virtualmin.service_info.options'] = '选项';
$lang['Virtualmin.service_info.server'] = '服务器';
$lang['Virtualmin.service_info.password'] = '密码';
$lang['Virtualmin.service_info.username'] = '用户名';
$lang['Virtualmin.tab_stats.info.maximum_mailboxes'] = '最大邮箱数';
$lang['Virtualmin.tab_stats.info.maximum_databases'] = '最大数据库数';
$lang['Virtualmin.tab_stats.info.databases_count'] = '数据库计数';
$lang['Virtualmin.tab_stats.info.databases_size'] = '数据库大小';
$lang['Virtualmin.tab_stats.info.disk_used'] = '使用的磁盘';
$lang['Virtualmin.tab_stats.info_heading.value'] = '价值';
$lang['Virtualmin.tab_stats.info_heading.field'] = '现场';
$lang['Virtualmin.tab_stats.info_title'] = '信息';
$lang['Virtualmin.tab_client_actions.field_password_submit'] = '更新密码';
$lang['Virtualmin.tab_client_actions.field_virtualmin_confirm_password'] = '确认密码';
$lang['Virtualmin.tab_client_actions.field_virtualmin_password'] = '密码';
$lang['Virtualmin.tab_client_actions.change_password'] = '更改密码';
$lang['Virtualmin.service_field.password'] = '密码';
$lang['Virtualmin.service_field.username'] = '用户名';
$lang['Virtualmin.service_field.domain'] = '域名';
$lang['Virtualmin.package_fields.template'] = '虚拟迷你模板';
$lang['Virtualmin.package_fields.plan'] = '虚拟货币计划';
$lang['Virtualmin.row_meta.account_limit'] = '账户限额';
$lang['Virtualmin.row_meta.use_ssl'] = '连接应用程序接口时使用 SSL（推荐）';
$lang['Virtualmin.row_meta.port'] = '港口';
$lang['Virtualmin.row_meta.password'] = '密码';
$lang['Virtualmin.row_meta.user_name'] = '用户名';
$lang['Virtualmin.row_meta.host_name'] = '主机名';
$lang['Virtualmin.row_meta.server_name'] = '服务器标签';
$lang['Virtualmin.edit_row.add_btn'] = '编辑服务器';
$lang['Virtualmin.edit_row.basic_title'] = '基本设置';
$lang['Virtualmin.edit_row.box_title'] = '编辑 VirtualMin 服务器';
$lang['Virtualmin.add_row.add_btn'] = '添加服务器';
$lang['Virtualmin.add_row.basic_title'] = '基本设置';
$lang['Virtualmin.add_row.box_title'] = '添加 VirtualMin 服务器';
$lang['Virtualmin.order_options.first'] = '第一个非满员服务器';
$lang['Virtualmin.manage.module_groups_no_results'] = '没有服务器组。';
$lang['Virtualmin.manage.module_rows_no_results'] = '没有服务器。';
$lang['Virtualmin.manage.module_groups.confirm_delete'] = '您确定要删除此服务器组吗？';
$lang['Virtualmin.manage.module_rows.confirm_delete'] = '您确定要删除这个服务器吗？';
$lang['Virtualmin.manage.module_groups.delete'] = '删除';
$lang['Virtualmin.manage.module_rows.delete'] = '删除';
$lang['Virtualmin.manage.module_groups.edit'] = '编辑';
$lang['Virtualmin.manage.module_rows.edit'] = '编辑';
$lang['Virtualmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['Virtualmin.manage.module_groups_heading.options'] = '选项';
$lang['Virtualmin.manage.module_groups_heading.servers'] = '服务器数量';
$lang['Virtualmin.manage.module_groups_heading.name'] = '组名';
$lang['Virtualmin.manage.module_rows_heading.options'] = '选项';
$lang['Virtualmin.manage.module_rows_heading.accounts'] = '账户';
$lang['Virtualmin.manage.module_rows_heading.port'] = '港口';
$lang['Virtualmin.manage.module_rows_heading.hostname'] = '主机名';
$lang['Virtualmin.manage.module_rows_heading.name'] = '服务器标签';
$lang['Virtualmin.manage.module_groups_title'] = '服务器组';
$lang['Virtualmin.manage.module_rows_title'] = '服务器';
$lang['Virtualmin.add_module_group'] = '添加服务器组';
$lang['Virtualmin.add_module_row'] = '添加服务器';
$lang['Virtualmin.tab_client_actions'] = '行动';
$lang['Virtualmin.tab_stats'] = '统计资料';
$lang['Virtualmin.module_group'] = '服务器组';
$lang['Virtualmin.module_row_plural'] = '服务器';
$lang['Virtualmin.module_row'] = '服务器';
$lang['Virtualmin.description'] = 'Virtualmin 是一个域名主机和网站控制面板，能够创建和管理多个域名，有开源和商业两个版本。它基于 Webmin。';
$lang['Virtualmin.name'] = 'VirtualMin';
$lang['Virtualmin.!error.meta[domains_list].valid'] = '一个或多个软件包域无效。';
$lang['Virtualmin.package_fields.tooltip.domains_list'] = '输入可提供子域名的 CSV 域名列表，如 "domain1.com,domain2.com,domain3.com"。';
$lang['Virtualmin.package_fields.domains_list'] = '可用域名列表';
$lang['Virtualmin.package_fields.sub_domains_disable'] = '禁用';
$lang['Virtualmin.package_fields.sub_domains_enable'] = '启用';
$lang['Virtualmin.package_fields.sub_domains'] = '启用销售子域名';
